wcwidth: Python support for wide characters in a terminal
=========================================================

Description
-----------

Measures number of Terminal column cells of wide-character codes

https://pypi.python.org/pypi/wcwidth
